@@ -1,6 +1,6 @@
 package Statocles;
 # ABSTRACT: A static site generator
-$Statocles::VERSION = '0.066';
+$Statocles::VERSION = '0.067';
 # The currently-running site.
 # I hate this, but I know of no better way to ensure that we always have access
 # to a Mojo::Log object, while still being relatively useful, without having to
@@ -28,7 +28,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 SYNOPSIS
 
@@ -139,7 +139,7 @@ Doug Bell <preaction@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Joel Berger tadegenban Vladimir Lettiev
+=for stopwords Joel Berger tadegenban Vladimir Lettiev William Lindley
 
 =over 4
 
@@ -155,6 +155,10 @@ tadegenban <tadegenban@gmail.com>
 
 Vladimir Lettiev <thecrux@gmail.com>
 
+=item *
+
+William Lindley <wlindley@wlindley.com>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
