@@ -1,6 +1,6 @@
 package Statocles::Command;
 # ABSTRACT: The statocles command-line interface
-$Statocles::Command::VERSION = '0.066';
+$Statocles::Command::VERSION = '0.067';
 use Statocles::Base 'Class';
 use Scalar::Util qw( blessed );
 use Getopt::Long qw( GetOptionsFromArray :config pass_through bundling no_auto_abbrev );
@@ -84,17 +84,14 @@ sub main {
     my $site = eval { $wire->get( $opt{site} ) };
 
     if ( $@ ) {
-        if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::NotFound' ) ) {
-            if ( $@->name eq $opt{site} ) {
-                warn sprintf qq{ERROR: Could not find site named "%s" in config file "%s"\n},
-                    $opt{site}, $opt{config};
-            }
-            else {
-                warn sprintf qq{ERROR: Could not create site object "%s": %s\n}, $opt{site}, $@;
-            }
+        if ( blessed $@ && $@->isa( 'Beam::Wire::Exception::NotFound' ) && $@->name eq $opt{site} ) {
+            warn sprintf qq{ERROR: Could not find site named "%s" in config file "%s"\n},
+                $opt{site}, $opt{config};
             return 1;
         }
-        die $@;
+        warn sprintf qq{ERROR: Could not create site object "%s" in config file "%s": %s\n},
+            $opt{site}, $opt{config}, $@;
+        return 1;
     }
 
     my $cmd = $class->new( site => $site );
@@ -595,7 +592,7 @@ Statocles::Command - The statocles command-line interface
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 SYNOPSIS
 
