@@ -1,6 +1,6 @@
 package Statocles::Document;
 # ABSTRACT: Base class for all Statocles documents
-$Statocles::Document::VERSION = '0.066';
+$Statocles::Document::VERSION = '0.067';
 use Statocles::Base 'Class';
 use Statocles::Image;
 
@@ -31,6 +31,13 @@ has author => (
 );
 
 
+has status => (
+    is => 'rw',
+    isa => Str,
+    default => 'published',
+);
+
+
 has content => (
     is => 'rw',
     isa => Str,
@@ -126,7 +133,7 @@ Statocles::Document - Base class for all Statocles documents
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 DESCRIPTION
 
@@ -177,6 +184,13 @@ C<&>) will be escaped by the template, so no HTML allowed.
 
 The author of this document. Optional.
 
+=head2 status
+
+The publishing status of this document.  Optional. Statocles apps can
+examine this to determine whether to turn a document into a page.  The
+default value is C<published>; other reasonable values could include
+C<draft> or C<private>.
+
 =head2 content
 
 The raw content of this document, in markdown. This is everything below
