@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.066';
+$Statocles::Page::VERSION = '0.067';
 use Statocles::Base 'Role';
 use Statocles::Template;
 use Statocles::Util qw( uniq_by );
@@ -87,7 +87,7 @@ has _links => (
     isa => LinkHash,
     lazy => 1,
     default => sub { +{} },
-    coercion => LinkHash->coercion,
+    coerce => LinkHash->coercion,
     init_arg => 'links',
 );
 
@@ -160,7 +160,12 @@ sub vars {
 sub render {
     my ( $self, %args ) = @_;
 
-    return $self->_rendered_html if $self->_has_rendered_html;
+    if ( $self->_has_rendered_html ) {
+        $self->site->log->debug( 'Render page (cached): ' . $self->path );
+        return $self->_rendered_html;
+    }
+
+    $self->site->log->debug( 'Render page: ' . $self->path );
 
     my %vars = (
         %{ $self->data },
@@ -229,7 +234,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 DESCRIPTION
 
@@ -276,6 +281,8 @@ A hash of arrays of links to pages related to this page. Possible keys:
 
     feed        - Feed pages related to this page
     alternate   - Alternate versions of this page posted to other sites
+    stylesheet  - Additional stylesheets for this page
+    script      - Additional scripts for this page
 
 Each item in the array is a L<link object|Statocles::Link>. The most common
 attributes are:
