@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render document objects into HTML
-$Statocles::Page::Document::VERSION = '0.066';
+$Statocles::Page::Document::VERSION = '0.067';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -16,7 +16,7 @@ has document => (
 
 has '+title' => (
     lazy => 1,
-    default => sub { $_[0]->document->title },
+    default => sub { $_[0]->document->title || '' },
 );
 
 
@@ -146,7 +146,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 DESCRIPTION
 
