@@ -1,6 +1,6 @@
 package Statocles::Site;
 # ABSTRACT: An entire, configured website
-$Statocles::Site::VERSION = '0.066';
+$Statocles::Site::VERSION = '0.067';
 use Statocles::Base 'Class', 'Emitter';
 use Scalar::Util qw( blessed );
 use Text::Markdown;
@@ -8,6 +8,7 @@ use Mojo::URL;
 use Mojo::DOM;
 use Mojo::Log;
 use Statocles::Page::Plain;
+use List::UtilsBy qw( uniq_by );
 
 
 has title => (
@@ -65,6 +66,37 @@ has _nav => (
 );
 
 
+has _links => (
+    is => 'ro',
+    isa => LinkHash,
+    default => sub { +{} },
+    coerce => LinkHash->coercion,
+    init_arg => 'links',
+);
+
+
+has images => (
+    is => 'ro',
+    isa => HashRef[InstanceOf['Statocles::Image']],
+    default => sub { +{} },
+    coerce => sub {
+        my ( $ref ) = @_;
+        my %img;
+        for my $name ( keys %$ref ) {
+            my $attrs = $ref->{ $name };
+            if ( !ref $attrs ) {
+                $attrs = { src => $attrs };
+            }
+            $img{ $name } = Statocles::Image->new(
+                %{ $attrs },
+            );
+        }
+        return \%img;
+    },
+);
+
+
+
 has build_store => (
     is => 'ro',
     isa => Store,
@@ -363,6 +395,18 @@ sub deploy {
 }
 
 
+sub links {
+    my ( $self, $name, $add_link ) = @_;
+    if ( $add_link ) {
+        push @{ $self->_links->{ $name } }, Link->coerce( $add_link );
+        return;
+    }
+    my @links = uniq_by { $_->href }
+        $self->_links->{ $name } ? @{ $self->_links->{ $name } } : ();
+    return wantarray ? @links : $links[0];
+}
+
+
 sub url {
     my ( $self, $path ) = @_;
     my $base    = $self->_write_deploy && $self->_write_deploy->base_url
@@ -391,7 +435,7 @@ Statocles::Site - An entire, configured website
 
 =head1 VERSION
 
-version 0.066
+version 0.067
 
 =head1 SYNOPSIS
 
@@ -466,6 +510,84 @@ are defined by your L<theme|Statocles::Theme>. For example:
         ],
     }
 
+=head2 links
+
+    # site.yml
+    links:
+        stylesheet:
+            - href: /theme/css/site.css
+        script:
+            - href: /theme/js/site.js
+
+Related links for this site. Links are used to build relationships
+to other web addresses. Link categories are named based on their
+relationship. Some possible categories are:
+
+=over 4
+
+=item stylesheet
+
+Additional stylesheets for this site.
+
+=item script
+
+Additional scripts for this site.
+
+=back
+
+Each category contains an arrayref of hashrefs of L<link objects|Statocles::Link>.
+See the L<Statocles::Link|Statocles::Link> documentation for a full list of
+supported attributes. The most common attributes are:
+
+=over 4
+
+=item href
+
+The URL for the link.
+
+=item text
+
+The text of the link. Not needed for stylesheet or script links.
+
+=back
+
+=head2 images
+
+    # site.yml
+    images:
+        icon: /images/icon.png
+
+Related images for this document. These are used by themes to display
+images in appropriate templates. Each image has a category, like
+C<title>, C<banner>, or C<icon>, mapped to an L<image
+object|Statocles::Image>.  See the L<Statocles::Image|Statocles::Image>
+documentation for a full list of supported attributes. The most common
+attributes are:
+
+=over 4
+
+=item src
+
+The source path of the image. Relative paths will be resolved relative
+to this document.
+
+=item alt
+
+The alternative text to display if the image cannot be downloaded or
+rendered. Also the text to use for non-visual media.
+
+=back
+
+Useful image names are:
+
+=over 4
+
+=item icon
+
+The shortcut icon for the site.
+
+=back
+
 =head2 build_store
 
 The L<store|Statocles::Store> object to use for C<build()>. This is a workspace
@@ -534,6 +656,24 @@ command-line.
 Deploy the site to its destination. The C<%options> are passed to the appropriate
 L<deploy object|Statocles::Deploy>.
 
+=head2 links
+
+    my @links = $site->links( $key );
+    my $link = $site->links( $key );
+    $site->links( $key => $add_link );
+
+Get or append to the links set for the given key. See L<the links
+attribute|/links> for some commonly-used keys.
+
+If only one argument is given, returns a list of L<link
+objects|Statocles::Link>. In scalar context, returns the first link in
+the list.
+
+If two arguments are given, append the new link to the given key.
+C<$add_link> may be a URL string, a hash reference of L<link
+attributes|Statocles::Link/ATTRIBUTES>, or a L<Statocles::Link
+object|Statocles::Link>. When adding links, nothing is returned.
+
 =head2 url
 
     my $url = $site->url( $page_url );
